@@ -1,18 +1,36 @@
 
-#' @title Build objects for hierarchical modeling
+#' @title Build input objects for hierarchical modeling
 #'
-#' @description This function constructs objects based on the provided inputs, either for home range (hr) or speed & distance continuous-time (ctsd).
+#' @description
+#' Constructs and organizes the required inputs for hierarchical models
+#' based on the provided simulation outputs and user specifications.
 #'
-#' @param rv A list containing outputs, settings and data objects. Must not be NULL.
-#' @param set_target Character. Research target: `"hr"` for home range or `"ctsd"` for speed & distance.
-#' @param subpop Logical. If TRUE, will run meta-analyses with groups. Default is FALSE.
-#' @param trace Logical. If TRUE, prints progress messages. Default is FALSE.
+#' @param rv A named list containing simulation inputs, settings, and
+#'   group assignments. Must not be NULL.
+#' @param set_target Character vector specifying the target metrics.
+#'   Options are "hr" (for home range area) and/or "ctsd" (for movement
+#'   speed). Defaults to c("hr", "ctsd").
+#' @param subpop Logical; if TRUE, analyzes population-level inferences
+#'   by subpopulations/groups (e.g., males vs. females). Requires group
+#'   assigments in `rv`.
+#' @param trace Logical; if TRUE, prints progress messages.
+#'   Default is FALSE.
 #'
 #' @return A list containing:
-#' \item{datList}{A list containing the inputs (and optionally, grouped inputs).}
-#' \item{outList}{A list of additional computed meta outputs.}
-#' \item{truthList}{A list of expected values derived from the target set.}
+#'   \describe{
+#'     \item{datList}{A named list containing the inputs
+#'       (and optionally, grouped inputs).}
+#'     \item{outList}{A named list of additional computed meta outputs.}
+#'     \item{truthList}{A named list of expected (true) values.}
+#' }
 #' 
+#' @details
+#' This function streamlines the preparation of inputs for hierarchical
+#' model workflows. It extracts, formats, and organizes the relevant data
+#' according to the chosen target, and optionally by group. The resulting
+#' lists facilitate downstream procedures and reporting.
+#' 
+#' @keywords internal
 #' @noRd
 .build_meta_objects <- function(rv,
                                 set_target = c("hr", "ctsd"),
@@ -140,55 +158,149 @@
   
 }
 
-#' @title Running hierarchical model meta-analyses (with resamples)
+
+#' @title Running hierarchical models (with resampling)
 #'
-#' @description This function performs a meta-analysis on movement tracking data, for mean home range area (AKDE) or continuous-time speed and distance (CTSD) estimates for a sampled population. It leverages the `ctmm` R package, specifically the `meta()` function, to obtain population-level mean parameters. This function helps to evaluate the significance of results under combination testing.
-#'
-#' @param rv A list containing outputs, settings and data objects. Must not be NULL.
-#' @param set_target Character. Research target: `"hr"` for home range or `"ctsd"` for speed & distance.
-#' @param subpop Logical. If TRUE, will run meta-analyses with groups. Default is FALSE.
-#' @param random Logical. If TRUE, samples random subsets of individuals. Default is FALSE.
-#' @param max_samples Integer. Maximum number of resamples when `random = TRUE`. Must be positive. Default is 100.
-#' @param iter_step Numeric. The size of each iteration step. Default is 2.
-#' @param trace Logical. If TRUE, prints progress messages. Default is FALSE.
-#' @param .automate_seq Logical. If TRUE, overwrites sequence automatically to improve plot readability. Default is FALSE.
-#' @param .only_max_m Logical. If TRUE, will only run the maximum number of individuals. Default is FALSE.
-#' @param .lists A list containing already created meta inputs. Default is NULL.
+#' @description
+#' This function performs meta-analyses on simulated animal tracking data,
+#' to estimate key movement metrics, such as mean home range area and/or
+#' mean movement speed for a sampled population. The function can also
+#' compare these metrics between two groups if specified.
 #' 
+#' When resampling is enabled, the function repeatedly draws random
+#' subsets of individuals from the available population to simulate how
+#' parameter estimates behave across varying population sample sizes.
+#' This resampling allows users to assess estimate variability as sample
+#' size increases or as individuals are resampled. For example, it can
+#' reveal if the mean home range area converges as more individuals are
+#' added to the sampled population.
+#' 
+#' This approach helps quantify the robustness and precision of estimated
+#' parameters under different sampling scenarios.
+#' 
+#' The function leverages core methods from the `ctmm` package:
+#'
+#' - `ctmm::akde()`: Computes home range areas using the Autocorrelated
+#'   Kernel Density Estimator (AKDE), which explicitly accounts for the
+#'   autocorrelation in animal movement data to produce statistically
+#'   robust space-use estimates.
+#' - `ctmm::speed()`: Computes Continuous-Time Speed and Distance (CTSD) 
+#'   estimates, providing biologically meaningful summaries of movement 
+#'   speed, which is proportional to distance traveled.
+#' These methods allow for robust comparisons across individuals, 
+#' groups, and resampling scenarios.
+#' 
+#' @param rv A named list containing simulation inputs, settings, and
+#'   group assignments. Must not be NULL.
+#' @param set_target Character vector specifying the target metrics.
+#'   Options are "hr" (for home range area) and/or "ctsd" (for movement
+#'   speed). Defaults to c("hr", "ctsd").
+#' @param subpop Logical; if TRUE, analyzes population-level inferences
+#'   by subpopulations/groups (e.g., males vs. females). Requires group
+#'   assigments in `rv`.
+#' @param random Logical; if TRUE, performs random sampling of individuals
+#'   using different combinations (up to max_draws).
+#' @param max_draws Integer; maximum number of random draws per
+#'   combination size when \code{random=TRUE}.
+#'   Ignored if \code{random=FALSE}.
+#' @param iter_step Integer. Step size used to increment the number of
+#'   individuals sampled in each iteration. For example, if 
+#'   `iter_step = 2`, the function will evaluate sample sizes of 2, 4,
+#'   6, etc., up to the maximum population sample size. Defaults to 2.
+#' @param trace Logical; if TRUE, prints progress messages.
+#'   Default is FALSE.
+#' @param ... Additional arguments for advanced control:
+#'   \describe{
+#'     \item{.only_max_m}{Logical. If `TRUE`, runs the meta-analysis
+#'       only at the maximum population sample size. Skips all
+#'       intermediate sample sizes.}
+#'     \item{.max_m}{Integer. Sets a user-defined maximum sample size
+#'       to use in the resampling sequence. Overrides the default,
+#'       which uses all available individuals.}
+#'     \item{.m}{Integer. Specifies exact sample size to use. Overrides
+#'       automatic sequence generation. Accepts a single value.}
+#'     \item{.automate_seq}{Logical. If `TRUE`, automatically generates
+#'       an informative and non-redundant sequence of sample sizes
+#'       for better plot readability and runtime efficiency.}
+#'     \item{.lists}{List (Optional). Supplies precomputed input
+#'       objects, generated via \code{.build_meta_objects()}.}
+#'   }
+#'
+#' @return A data frame summarizing all outputs for each target,
+#'   population sample size, sample, and group (if specified). Columns
+#'   include:
+#'   \describe{
+#'     \item{type}{Research target, e.g., "hr" or "ctsd".}
+#'     \item{m}{Number of individuals in the sample.}
+#'     \item{sample}{Sample index (for repeated draws).}
+#'     \item{truth}{True value.}
+#'     \item{est}{Point estimate.}
+#'     \item{lci}{Lower confidence interval.}
+#'     \item{uci}{Upper confidence interval.}
+#'     \item{error}{Relative error.}
+#'     \item{error_lci}{Lower CI for relative error.}
+#'     \item{error_uci}{Upper CI for relative error.}
+#'     \item{ratio_truth}{True group ratio (A/B), if subpop=TRUE.}
+#'     \item{ratio_est}{Estimated group ratio.}
+#'     \item{ratio_lci}{Lower CI for estimated group ratio.}
+#'     \item{ratio_uci}{Upper CI for estimated group ratio.}
+#'     \item{overlaps}{Logical; whether estimate overlaps with the truth.}
+#'     \item{is_grouped}{Logical; TRUE if grouped.}
+#'     \item{group}{Group label ("All", "A", "B").}
+#'     \item{subpop_detected}{Logical; was a subpopulation detected?}
+#'   }
+#'
 #' @examples
 #' if(interactive()) {
-#' run_meta_resampled(rv, set_target = "hr")
+#'    run_meta_resamples(rv, set_target = "hr")
 #' }
 #'
+#' @seealso
+#'   \code{\link[ctmm]{akde}}, \code{\link[ctmm]{speed}},
+#' 
 #' @encoding UTF-8
-#' @return A data frame containing meta-analysis outputs, including estimates, errors, confidence intervals, and group information.
 #' @author Inês Silva \email{i.simoes-silva@@hzdr.de}
 #' 
+#' @keywords internal
 #' @export
-run_meta_resampled <- function(rv,
+run_meta_resamples <- function(rv,
                                set_target = c("hr", "ctsd"),
                                subpop = FALSE,
                                random = FALSE,
-                               max_samples = 100,
+                               max_draws = 100,
                                iter_step = 2,
                                trace = FALSE,
-                               .automate_seq = FALSE,
-                               .only_max_m = FALSE,
-                               .lists = NULL) {
+                               ...) {
+  
+  `%||%` <- function(x, y) if (!is.null(x)) x else y
+  
+  dots <- list(...)
+  .only_max_m <- dots[[".only_max_m"]] %||% FALSE
+  .max_m <- dots[[".max_m"]] %||% NULL
+  .m <- dots[[".m"]] %||% NULL
+  .lists <- dots[[".lists"]] %||% NULL
+  .automate_seq <- dots[[".automate_seq"]] %||% FALSE
   
   if (!is.logical(random) || length(random) != 1) {
     stop("'random' must be a single logical value (TRUE or FALSE)")
   }
   
-  if (random) {
-    if (!is.numeric(max_samples) ||
-        length(max_samples) != 1 ||
-        max_samples <= 0) {
-      stop("'max_samples' must be a single positive numeric value",
-           " when 'random' is TRUE")
+  if (random && (!is.numeric(max_draws) ||
+                 length(max_draws) != 1 ||
+                 max_draws <= 0))
+    stop("'max_draws' must be a single positive numeric",
+         " value when 'random' is TRUE")
+  if (!random) max_draws <- 1
+  
+  if (!is.null(.m)) {
+    if (!is.numeric(.m) || .m %% 1 != 0 || .m < 1) {
+      stop("'.m' must be a positive integer.")
+    }
+    if (.m > length(rv$simList)) {
+      stop(sprintf(
+        "Argument `.m` (%d) exceeds number of simulations (%d)!",
+        .m, length(rv$simList)))
     }
-  } else {
-    max_samples <- 1
   }
   
   dt_meta <- data.frame(
@@ -214,23 +326,22 @@ run_meta_resampled <- function(rv,
   datList <- truthList <- NULL
   
   if (is.null(.lists)) {
-    lists <- .build_meta_objects(rv, 
-                                 set_target = set_target,
-                                 subpop = subpop,
-                                 trace = trace)
+    .lists <- .build_meta_objects(rv, 
+                                  set_target = set_target,
+                                  subpop = subpop,
+                                  trace = trace)
   }
   
-  list2env(lists, envir = environment())
+  list2env(.lists, envir = environment())
   
   true_estimate <- c()
   true_ratio <- c()
   
   out <- lapply(set_target, function(target) {
     
-    if (trace) {
-      if (target == "hr") message("-- Running for home range:")
-      if (target == "ctsd") message("-- Running for speed:")
-    }
+    if (trace) message(
+      sprintf("-- Running for %s:",
+              ifelse(target == "hr", "home range", "speed")))
     
     if (target == "hr") {
       true_estimate[[target]] <- truthList[["hr"]][["All"]]$area
@@ -267,16 +378,19 @@ run_meta_resampled <- function(rv,
       input <- c(input, input_groups)
     }
     
-    m_iter <- NULL
-    if (.automate_seq) m_iter <- .get_sequence(input[["All"]],
-                                               .iter_step = iter_step,
-                                               grouped = subpop)
-    else m_iter <- seq(
-      2, length(input[["All"]]), by = iter_step)
+    m_seq <- NULL
+    if (is.null(.m)) {
+      m_seq <- .get_sequence(input[["All"]],
+                             .step = iter_step,
+                             .max_m = .max_m,
+                             .automate_seq = .automate_seq,
+                             grouped = subpop)
+      if (.only_max_m) m_seq <- max(m_seq)
+    } else {
+      m_seq <- .m
+    }
     
-    if (.only_max_m) m_iter <- max(m_iter)
-    
-    for (m in m_iter) {
+    for (m in m_seq) {
       if (m == 1) next
       
       if (trace) {
@@ -285,6 +399,7 @@ run_meta_resampled <- function(rv,
       }
       
       arg <- setNames(lapply(input, function(x) {
+        
         sets <- .get_sets(x, set_size = m)
         if (sets$sets == 1) return(sets)
         
@@ -297,9 +412,9 @@ run_meta_resampled <- function(rv,
           }
           
           out_random <- dplyr::distinct(as.data.frame(out_random))
-          if (nrow(out_random) > max_samples) {
+          if (nrow(out_random) > max_draws) {
             out_random <- out_random[
-              sample(nrow(out_random), max_samples), , drop = FALSE]
+              sample(nrow(out_random), max_draws), , drop = FALSE]
           }
           
           sets$out_random <- out_random
@@ -310,7 +425,7 @@ run_meta_resampled <- function(rv,
       }), names(input))
       
       n_samples <- 1
-      if (random && max_samples > 1) {
+      if (random && max_draws > 1) {
         n_samples <- if(subpop) nrow(arg[["A"]]$out_random) else 
           nrow(arg[["All"]]$out_random)
         
@@ -318,7 +433,7 @@ run_meta_resampled <- function(rv,
         } else { if (arg[["All"]]$sets == 1) n_samples <- 1 }
       }
       
-      msg_error <- "Error during combination testing."
+      msg_error <- "Error during resampling."
       if (length(n_samples) == 0) stop(msg_error)
       
       for (sample in seq_len(n_samples)) {
@@ -534,7 +649,7 @@ run_meta_resampled <- function(rv,
       if (trace) {
         message("Elapsed time:")
         elapsed <- Sys.time() - start_t
-        cat("Elapsed time since start:", format(elapsed), "\n")
+        cat(format(elapsed), "\n")
       }
       
     } # end of [m] loop [based on the number of individuals]
@@ -547,28 +662,89 @@ run_meta_resampled <- function(rv,
   
 }
 
+
 #' @title Running hierarchical models
 #'
-#' @description This function wraps around the `run_meta_resampled` function to run hierarchical models (with no resamples) for a quick evaluation.
+#' @description
+#' Performs hierarchical meta-analyses on animal movement simulation
+#' outputs to estimate key movement metrics, such as mean home range area
+#' and/or mean movement speed for a sampled population. The function can
+#' also compare these metrics between two groups (via ratios) if specified.
 #' 
-#' @inheritParams run_meta_resampled
+#' The function leverages core methods from the `ctmm` package:
+#'
+#' - `ctmm::akde()`: Computes home range areas using the Autocorrelated
+#'   Kernel Density Estimator (AKDE), which explicitly accounts for the
+#'   autocorrelation in animal movement data to produce statistically
+#'   robust space-use estimates.
+#' - `ctmm::speed()`: Computes Continuous-Time Speed and Distance (CTSD) 
+#'   estimates, providing biologically meaningful summaries of movement 
+#'   speed, which is proportional to distance traveled.
+#' These methods allow for robust comparisons across individuals, 
+#' groups, and resampling scenarios.
 #' 
-#' @return The outputs of the `run_meta_resampled` function for a single combination.
+#' Optionally, the function performs resampling by randomly drawing
+#' multiple sets of individuals from the population, allowing assessment
+#' of estimate variability as sample size increases or as individuals are
+#' resampled. This approach helps quantify the precision and reliability
+#' of estimates under different sampling scenarios.
+#' 
+#' Internally, this function wraps [`run_meta_resamples()`] to fit
+#' hierarchical models without resampling for initial evaluation.
+#' 
+#' @inheritParams run_meta_resamples
+#' 
+#' @return A data frame summarizing all outputs for each target,
+#'   population sample size, and group (if specified) for a single
+#'   draw (sample). Columns include:
+#'   \describe{
+#'     \item{type}{Research target, e.g., `hr` and/or `ctsd`.}
+#'     \item{m}{Number of individuals in the sample.}
+#'     \item{sample}{Sample index (for repeated draws).}
+#'     \item{truth}{True, expected value.}
+#'     \item{est}{Point estimate.}
+#'     \item{lci}{Lower confidence interval.}
+#'     \item{uci}{Upper confidence interval.}
+#'     \item{error}{Relative error.}
+#'     \item{error_lci}{Lower CI for relative error.}
+#'     \item{error_uci}{Upper CI for relative error.}
+#'     \item{ratio_truth}{True group ratio (A/B), if subpop=TRUE.}
+#'     \item{ratio_est}{Estimated group ratio.}
+#'     \item{ratio_lci}{Lower CI for estimated group ratio.}
+#'     \item{ratio_uci}{Upper CI for estimated group ratio.}
+#'     \item{overlaps}{Logical; whether estimate overlaps with the truth.}
+#'     \item{is_grouped}{Logical; `TRUE` if grouped.}
+#'     \item{group}{Group label (`All`, `A`, `B`).}
+#'     \item{subpop_detected}{Logical; was a subpopulation detected?}
+#'   }
+#' 
+#' @note
+#' This function is intended for internal use and may assume inputs
+#' follow specific structure and constraints not referenced explicitly.
+#' 
+#' @seealso 
+#' [`run_meta_resamples()`],
+#' [`ctmm::akde()`],
+#' [`ctmm::speed()`]
+#' 
+#' @keywords internal
 #' @export
 run_meta <- function(rv,
                      set_target = c("hr", "ctsd"),
                      subpop = FALSE, 
                      trace = FALSE,
                      iter_step = 2,
-                     .automate_seq = FALSE,
-                     .only_max_m = FALSE,
-                     .lists = NULL) {
+                     ...) {
+  dots <- list(...)
+  .automate_seq <- dots[[".automate_seq"]] %||% FALSE
+  .only_max_m <- dots[[".only_max_m"]] %||% FALSE
+  .lists <- dots[[".lists"]] %||% NULL
   
-  return(run_meta_resampled(rv,
+  return(run_meta_resamples(rv,
                             set_target = set_target,
                             subpop = subpop,
                             random = FALSE,
-                            max_samples = NULL,
+                            max_draws = NULL,
                             trace = trace,
                             iter_step = iter_step,
                             .automate_seq = .automate_seq,
@@ -579,399 +755,156 @@ run_meta <- function(rv,
 
 #' @title Running LOOCV on hierarchical model outputs
 #'
-#' @description This function runs hierarchical models on movement tracking data,
-#' for mean home range area (AKDE) or continuous-time speed and distance (CTSD)
-#' estimates for a sampled population. It leverages the `ctmm` R package,
-#' specifically the `meta()` function, to obtain population-level mean parameters.
-#' This function helps to assess outputs via leave-one-out cross-validation (LOOCV).
+#' @description
+#' Performs Leave-One-Out Cross-Validation (LOOCV) on hierarchical model
+#' outputs to assess the influence of individual simulated animals on
+#' population-level estimates. Supports analyses with or without
+#' groups.
 #'
-#' @param rv A list containing outputs, settings and data objects. Must not be NULL.
-#' @param set_target Character. Research target: `"hr"` for home range or `"ctsd"` for speed & distance.
-#' @param subpop Logical. If TRUE, will run meta-analyses with groups. Default is FALSE.
-#' @param trace Logical. If TRUE, prints progress messages. Default is FALSE.
-#' @param .only_max_m Logical. If TRUE, will only run the maximum number of individuals. Default is FALSE.
-#' @param .progress Logical. If TRUE, will display a progress bar. Default is FALSE.
-#' @param .lists A list containing already created meta inputs. Default is NULL.
+#' In each iteration, the function removes one individual, refits
+#' the hierarchical model to the remaining dataset, and recalculates
+#' the target population-level estimates. This process is repeated until
+#' every individual has been excluded once.
+#'
+#' This approach provides insight into how sensitive overall conclusions 
+#' are to specific individuals. This helps identify influential
+#' individuals and assess robustness.
+#' 
+#' @param rv A `reactiveValues` object or list containing simulation
+#'   inputs, fitted models, and (optionally) group assignments.
+#' @param set_target Character vector specifying the target metrics.
+#'   Options are `"hr"` for home range area and/or `"ctsd"` for movement
+#'   speed. Defaults to `c("hr", "ctsd")`.
+#' @param subpop Logical; if `TRUE`, analyzes population-level inferences
+#'   by groups (e.g., males vs. females). Requires valid group
+#'   assigments in `rv`.
+#' @param trace Logical; if `TRUE`, prints progress and diagnostic
+#'   messages. Default is `FALSE`.
+#' @param ... Additional arguments for advanced control:
+#'   \describe{
+#'     \item{.only_max_m}{Logical. If `TRUE`, runs the meta-analysis
+#'       only at the maximum population sample size, skipping all
+#'       intermediate sample sizes.}
+#'     \item{.progress}{Integer. Displays a progress bar.}
+#'     \item{.m}{Integer. Specifies exact sample size to use. Overrides
+#'       automatic sequence generation. Accepts a single value.}
+#'     \item{.lists}{List (optional); supplies precomputed input objects,
+#'       typically created via `.build_meta_objects()`.}
+#'   }
 #' 
 #' @examples
 #' if(interactive()) {
-#' run_meta_loocv(rv, set_target = "hr")
+#'    run_meta_loocv(rv, set_target = "hr")
 #' }
 #'
+#' @return A data frame containing summarized simulation outputs.
 #' @encoding UTF-8
-#' @return A data frame containing meta-analysis outputs, including estimates, errors, confidence intervals, and group information.
 #' @author Inês Silva \email{i.simoes-silva@@hzdr.de}
 #' 
+#' @keywords internal
 #' @export
 run_meta_loocv <- function(rv,
                            set_target = c("hr", "ctsd"),
                            subpop = FALSE,
                            trace = FALSE,
-                           .progress = FALSE,
-                           .only_max_m = TRUE,
-                           .lists = NULL) {
+                           ...) {
   
+  dots <- list(...)
+  .only_max_m <- dots[[".only_max_m"]] %||% TRUE
+  .max_m <- dots[[".max_m"]] %||% NULL
+  .progress <- dots[[".progress"]] %||% FALSE
+  .lists <- dots[[".lists"]] %||% NULL
+  
+  pb <- NULL
   dt_meta <- NULL
   
-  if (inherits(rv, "reactivevalues"))
-    rv_list <- reactiveValuesToList(rv) else rv_list <- rv
+  if (inherits(rv, "reactivevalues")) {
+    rv_list <- reactiveValuesToList(rv)
+  } else { rv_list <- rv }
+  
+  out <- lapply(set_target, function(target) {
     
-    out <- lapply(set_target, function(target) {
+    if (target == "ctsd") {
+      is_ctsd <- !.check_for_inf_speed(rv_list$ctsdList)
+      simList <- rv_list$simList[is_ctsd]
+      ctsdList <- rv_list$ctsdList[is_ctsd]
+    } else {
+      simList <- rv_list$simList
+    }
+    
+    if (length(simList) == 0) return(NULL)
+    
+    n_total <- length(simList)
+    if (n_total == 0) return(NULL)
+    max_m <- if (is.null(.max_m)) n_total else min(.max_m, n_total)
+    
+    if (.progress) {
+      pb <- txtProgressBar(min = 1, max = max_m, style = 3)
+    }
+    
+    x <- 1
+    for (x in seq_len(max_m)) {
       
-      if (target == "ctsd") {
-        is_ctsd <- !.check_for_inf_speed(rv_list$ctsdList)
-        simList <- rv_list$simList[is_ctsd]
-        ctsdList <- rv_list$ctsdList[is_ctsd]
-      } else {
-        simList <- rv_list$simList
+      if (trace) message(sprintf("--- %d out of %d", x, max_m))
+      
+      sim_idx <- seq_len(max_m)
+      tmp_file <- rlang::duplicate(rv_list, shallow = FALSE)
+      
+      tmp_file$seedList <- rv_list$seedList[sim_idx][-x]
+      tmp_file$simList <- simList[sim_idx][-x]
+      tmp_file$simfitList <- rv_list$simfitList[sim_idx][-x]
+      if (target == "hr") 
+        tmp_file$akdeList <- rv_list$akdeList[sim_idx][-x]
+      if (target == "ctsd") 
+        tmp_file$ctsdList <- ctsdList[sim_idx][-x]
+      tmp_file$seedList <- rv_list$seedList[sim_idx][-x]
+      
+      if (target == "ctsd" && length(tmp_file$ctsdList) > 0) {
+        tmp_file$ctsdList[sapply(tmp_file$ctsdList, is.null)] <- NULL
+        
+        new_i <- 0
+        new_list <- list()
+        for (i in seq_along(tmp_file$ctsdList)) {
+          if (tmp_file$ctsdList[[i]]$CI[, "est"] != "Inf") {
+            new_i <- new_i + 1
+            new_list[[new_i]] <- tmp_file$ctsdList[[i]]
+          }
+        }
+        
+        if (length(new_list) == 0) new_list <- NULL
+        
+        tmp_file$ctsdList <- new_list
+        tmp_file$ctsdList[sapply(tmp_file$ctsdList, is.null)] <- NULL
+        
+      } # end of if (target == "ctsd" &&
+      #              length(tmp_file$ctsdList) > 0)
+      
+      tmp_dt <- NULL
+      tmp_dt <- run_meta(tmp_file,
+                         set_target = target,
+                         .only_max_m = TRUE,
+                         .automate_seq = TRUE)
+      
+      if (nrow(tmp_dt) > 0) {
+        tmp_dt$x <- x
+        if (is.null(dt_meta)) {
+          dt_meta <- tmp_dt
+        } else {
+          dt_meta <- rbind(dt_meta, tmp_dt)
+        }
       }
-      
-      if (length(simList) == 0) return(NULL)
-      
       if (.progress) {
-        total_steps <- length(simList)
-        pb <- txtProgressBar(min = 0, max = total_steps, style = 3)
+        setTxtProgressBar(pb, x)
       }
       
-      x <- 1
-      for (x in seq_along(simList)) {
-        
-        if (trace)
-          message(paste("---", x, "out of", length(rv_list$simList)))
-        
-        tmp_file <- rlang::duplicate(rv_list, shallow = FALSE)
-        tmp_file$seedList <- rv_list$seedList[-x]
-        tmp_file$simList <- simList[-x]
-        tmp_file$simfitList <- rv_list$simfitList[-x]
-        if (target == "hr") tmp_file$akdeList <- rv_list$akdeList[-x]
-        if (target == "ctsd") tmp_file$ctsdList <- ctsdList[-x]
-        tmp_file$seedList <- rv_list$seedList[-x]
-        
-        if (target == "ctsd" && length(tmp_file$ctsdList) > 0) {
-          tmp_file$ctsdList[sapply(tmp_file$ctsdList, is.null)] <- NULL
-          
-          new_i <- 0
-          new_list <- list()
-          for (i in seq_along(tmp_file$ctsdList)) {
-            if (tmp_file$ctsdList[[i]]$CI[, "est"] != "Inf") {
-              new_i <- new_i + 1
-              new_list[[new_i]] <- tmp_file$ctsdList[[i]]
-            }
-          }
-          
-          if (length(new_list) == 0) new_list <- NULL
-          
-          tmp_file$ctsdList <- new_list
-          tmp_file$ctsdList[sapply(tmp_file$ctsdList, is.null)] <- NULL
-          
-        } # end of if (target == "ctsd" &&
-        #              length(tmp_file$ctsdList) > 0)
-        
-        tmp_dt <- NULL
-        tmp_dt <- run_meta(tmp_file, 
-                           set_target = target,
-                           .only_max_m = TRUE,
-                           .automate_seq = TRUE)
-        
-        if (nrow(tmp_dt) > 0) {
-          tmp_dt$x <- x
-          if (is.null(dt_meta)) {
-            dt_meta <- tmp_dt
-          } else {
-            dt_meta <- rbind(dt_meta, tmp_dt)
-          }
-        }
-        if (.progress) {
-          setTxtProgressBar(pb, x)
-        }
-        
-      } # end of [x] loop (individuals)
-      
-      return(dt_meta)
-      
-    }) # end of [set_target] lapply
+    } # end of [x] loop (individuals)
     
-    # close(pb)
+    return(dt_meta)
     
-    return(dplyr::distinct(do.call(rbind, out)))
-    
-}
-
-
-#' @title Plot meta (combinations)
-#'
-#' @noRd 
-#' 
-plot_meta_combinations <- function(rv,
-                                   set_target = c("hr", "ctsd"),
-                                   random = FALSE, 
-                                   subpop = FALSE, 
-                                   colors = NULL) {
+  }) # end of [set_target] lapply
   
-  stopifnot(!is.null(rv$meta_tbl),
-            !is.null(rv$which_m),
-            !is.null(rv$which_meta),
-            !is.null(rv$which_question),
-            !is.null(set_target))
-  if (length(rv$simList) <= 1)
-    stop("simList must have more than one element.")
-  if (random) {
-    stopifnot(!is.null(rv$meta_tbl_resample),
-              !is.null(rv$error_threshold))
-  }
-  if (rv$which_meta == "compare") {
-    stopifnot(!is.null(rv$metaList_groups),
-              !is.null(rv$metaList[[set_target]]))
-  }
+  if (.progress) close(pb)
   
-  dodge_width <- 0.25
-  txt_title <- if (length(rv$which_question) > 1) {
-    ifelse(set_target == "hr", 
-           "For home range:", "For speed & distance:")
-  }
-  
-  if (is.null(colors)) { pal_values <- c(
-    "Yes" = "#009da0", "Near" = "#77b131", "No" = "#dd4b39")
-  } else pal_values <- c(
-    "Yes" = colors[[1]], "Near" = colors[[2]], "No" = colors[[3]])
-  
-  if (random) {
-    
-    if (!is.null(rv$meta_nresample))
-      out <- dplyr::filter(rv$meta_tbl_resample,
-                           .data$sample <= rv$meta_nresample)
-    else out <- rv$meta_tbl_resample
-    
-    out <- out %>% 
-      dplyr::mutate(m = as.integer(.data$m)) %>% 
-      dplyr::filter(.data$type == set_target)
-    if (subpop) out <- dplyr::filter(out, .data$group != "All")
-    
-    stopifnot(all(!is.na(out$est)), nrow(out) > 0)
-    
-    max_samples <- max(unique(out$sample))
-    max_samples
-    
-    out_mean <- out %>% 
-      dplyr::group_by(.data$type, .data$group, .data$m) %>% 
-      dplyr::summarize(
-        n = dplyr::n(),
-        error = mean(.data$error, na.rm = TRUE),
-        error_lci = mean(.data$error_lci, na.rm = TRUE),
-        error_uci = mean(.data$error_uci, na.rm = TRUE)) %>%
-      dplyr::rowwise() %>%
-      dplyr::mutate(
-        within_threshold = 
-          (.data$error >= -rv$error_threshold &
-             .data$error <= rv$error_threshold),
-        overlaps_with_threshold = 
-          (.data$error_lci <= rv$error_threshold & 
-             .data$error_uci >= -rv$error_threshold),
-        status = dplyr::case_when(
-          within_threshold ~ "Yes",
-          !within_threshold & overlaps_with_threshold ~ "Near",
-          TRUE ~ "No")) %>% 
-      quiet() %>% 
-      suppressMessages() %>% 
-      suppressWarnings()
-    
-    txt_color <- paste0(
-      "Within error threshold (\u00B1",
-      rv$error_threshold * 100, "%)?")
-    
-    plot_subtitle <- paste(
-      "<b>Maximum number of samples:</b>", max_samples)
-    
-    p.optimal <- out_mean %>% 
-      ggplot2::ggplot(
-        ggplot2::aes(x = as.factor(.data$m),
-                     y = .data$error,
-                     group = .data$group,
-                     shape = .data$group,
-                     color = .data$status)) + 
-      
-      ggplot2::geom_hline(
-        yintercept = 0,
-        linewidth = 0.3,
-        linetype = "solid") +
-      
-      ggplot2::geom_hline(
-        yintercept = rv$error_threshold,
-        color = "black",
-        linetype = "dotted") +
-      ggplot2::geom_hline(
-        yintercept = -rv$error_threshold,
-        color = "black",
-        linetype = "dotted") +
-      
-      ggplot2::geom_jitter(
-        data = out,
-        mapping = ggplot2::aes(x = as.factor(.data$m),
-                               y = .data$error,
-                               group = .data$group,
-                               shape = .data$group,
-                               color = .data$status),
-        position = ggplot2::position_jitterdodge(dodge.width = 0.4),
-        size = 3.5, color = "grey80", alpha = 0.9) +
-      
-      ggplot2::geom_linerange(
-        ggplot2::aes(ymin = .data$error_lci,
-                     ymax = .data$error_uci),
-        show.legend = TRUE,
-        position = ggplot2::position_dodge(width = 0.4),
-        linewidth = 2.2, alpha = 0.3) +
-      ggplot2::geom_point(
-        position = ggplot2::position_dodge(width = 0.4),
-        show.legend = TRUE,
-        size = 3.5) +
-      
-      ggplot2::labs(
-        title = txt_title,
-        subtitle = plot_subtitle,
-        x = "<i>Population</i> sample size, <i>m</i>",
-        y = "Relative error (%)",
-        color = txt_color) +
-      
-      ggplot2::scale_y_continuous(breaks = scales::breaks_pretty(),
-                                  labels = scales::percent) +
-      
-      ggplot2::scale_color_manual(values = pal_values,
-                                  na.translate = FALSE, drop = FALSE) +
-      ggplot2::scale_shape_manual("Group:", values = c(16, 18)) +
-      
-      ggplot2::theme_minimal() +
-      ggplot2::theme(
-        legend.position = "bottom",
-        plot.title = ggtext::element_markdown(
-          size = 15, face = 2, hjust = 1,
-          margin = ggplot2::margin(b = 2)),
-        plot.subtitle = ggtext::element_markdown(
-          size = 14, hjust = 1, margin = ggplot2::margin(b = 15)))
-    p.optimal
-    
-    if (rv$which_meta == "mean") {
-      p.optimal <- p.optimal +
-        ggplot2::guides(shape = "none")
-    }
-    
-  } else {
-    
-    out <- out_all <- dplyr::distinct(rv$meta_tbl) %>% 
-      dplyr::select(-c(.data$est, .data$lci, .data$uci)) %>%
-      dplyr::filter(.data$type == set_target)
-    
-    stopifnot(all(!is.na(out$est)), nrow(out) > 0)
-    
-    if (subpop) out <- dplyr::filter(out, .data$group != "All")
-    
-    stopifnot(all(!is.na(out$est)), nrow(out) > 0)
-    
-    txt_color <- paste0(
-      "Within error threshold (\u00B1",
-      rv$error_threshold * 100, "%)?")
-    
-    out <- out %>%
-      dplyr::group_by(.data$type) %>% 
-      dplyr::rowwise() %>%
-      dplyr::mutate(
-        within_threshold = 
-          (.data$error >= -rv$error_threshold & 
-             .data$error <= rv$error_threshold),
-        overlaps_with_threshold = 
-          (.data$error_lci <= rv$error_threshold & 
-             .data$error_uci >= -rv$error_threshold),
-        color = dplyr::case_when(
-          within_threshold ~ "Yes",
-          !within_threshold & overlaps_with_threshold ~ "Near",
-          TRUE ~ "No"))
-    
-    txt_caption <- NULL
-    txt_color <- paste0(
-      "Within error threshold (\u00B1", rv$error_threshold * 100, "%)?")
-    
-    if (rv$which_meta == "compare") {
-      dodge_width <- .4
-      txt_color <- "Group:"
-      
-      is_subpop <- rv$metaList_groups[["intro"]][[
-        set_target]]$logs$subpop_detected
-      
-      is_final_subpop <- out_all %>%
-        dplyr::filter(.data$group == "All") %>%
-        dplyr::pull(.data$subpop_detected)
-      is_final_subpop <- rep(is_final_subpop, each = 2)
-      is_final_subpop <- out$is_final_subpop <- ifelse(
-        is_final_subpop == "FALSE", "No", "Yes")
-      out$color <- out$group
-      
-      pal_values <- c("A" = "#77b131", "B" = "#009da0")
-      
-      txt_color <- "Groups:"
-      txt_caption <- "(*) Asterisks indicate subpopulations were found."
-      
-    } # Note: refers to finding subpops within the population.
-    
-    p.optimal <- out %>%
-      ggplot2::ggplot(
-        ggplot2::aes(x = as.factor(.data$m),
-                     y = .data$error,
-                     group = .data$group,
-                     shape = .data$group,
-                     color = .data$color)) +
-      
-      ggplot2::geom_hline(
-        yintercept = rv$error_threshold,
-        color = "black",
-        linetype = "dotted") +
-      ggplot2::geom_hline(
-        yintercept = -rv$error_threshold,
-        color = "black",
-        linetype = "dotted") +
-      
-      ggplot2::geom_hline(
-        yintercept = 0,
-        linewidth = 0.3,
-        linetype = "solid") +
-      ggplot2::geom_point(
-        size = 4,
-        position = ggplot2::position_dodge(width = dodge_width)) +
-      ggplot2::geom_linerange(
-        ggplot2::aes(ymin = .data$error_lci,
-                     ymax = .data$error_uci),
-        position = ggplot2::position_dodge(width = dodge_width)) +
-      
-      { if (rv$which_meta == "compare")
-        ggplot2::geom_text(
-          data = subset(out, .data$subpop_detected == TRUE),
-          mapping = ggplot2::aes(x = as.factor(.data$m),
-                                 y = .data$error_uci + 0.05,
-                                 label = "*"),
-          color = "black", size = 5, 
-          position = ggplot2::position_dodge(width = 0.4))
-        
-      } +
-      
-      ggplot2::labs(
-        title = txt_title,
-        x = "<i>Population</i> sample size, <i>m</i>",
-        y = "Relative error (%)",
-        color = txt_color,
-        caption = txt_caption) +
-      
-      ggplot2::scale_y_continuous(labels = scales::percent,
-                                  breaks = scales::breaks_pretty()) +
-      ggplot2::scale_color_manual(txt_color, values = pal_values) +
-      ggplot2::scale_shape_manual("Group:", values = c(16, 18)) +
-      ggplot2::theme_minimal() +
-      ggplot2::theme(legend.position = "bottom")
-    
-    if (rv$which_meta == "mean") {
-      p.optimal <- p.optimal +
-        ggplot2::guides(shape = "none")
-    }
-    
-  } # end of (!random)
-  
-  return(p.optimal)
+  return(dplyr::distinct(do.call(rbind, out)))
   
 }
