@@ -663,20 +663,24 @@ mod_tab_hrange_server <- function(id, rv) {
       req(rv$hrErr,
           rv$simList,
           rv$which_meta)
+      req(rv$which_meta == "none")
       
       ci <- suppressWarnings(bayestestR::ci(
         rv$hrErr$est, ci = .95, method = "HDI"))
       lci <- ci$CI_low
       uci <- ci$CI_high
       
-      if (rv$which_meta != "none") extra_ui <- tagList(
-        "To obtain valid credible intervals, run more simulations",
-        "through the", span("Simulations", class = "cl-grn"), "box.")
-      else extra_ui <- tagList(
-        "To obtain valid credible intervals, select a different",
-        span("analytical target", class = "cl-sea"), "in the",
-        icon("house", class = "cl-mdn"),
-        span("Home", class = "cl-mdn"), "tab.")
+      if (rv$which_meta != "none") {
+        extra_ui <- tagList(
+          "To obtain valid credible intervals, run more simulations",
+          "through the", span("Simulations", class = "cl-grn"), "box.")
+      } else {
+        extra_ui <- tagList(
+          "To obtain valid credible intervals, select a different",
+          span("analytical target", class = "cl-sea"), "in the",
+          icon("house", class = "cl-mdn"),
+          span("Home", class = "cl-mdn"), "tab.")
+      }
       
       ui <- ""
       if (length(rv$simList) > 1) {
@@ -1091,8 +1095,8 @@ mod_tab_hrange_server <- function(id, rv) {
         seed = rv$seedList,
         sigma = rv$sigma,
         
-        emulated = rv$is_emulate,
-        fit = if (rv$is_emulate) rv$meanfitList else NULL,
+        ind_var = rv$add_ind_var,
+        fit = if (rv$add_ind_var) rv$meanfitList else NULL,
         
         grouped = rv$grouped,
         groups = if (rv$grouped) rv$groups[[2]] else NULL)
@@ -1169,7 +1173,7 @@ mod_tab_hrange_server <- function(id, rv) {
           group <- ifelse(nm %in% rv$groups[[2]]$A, "A", "B")
         }
         
-        if (rv$is_emulate) {
+        if (rv$add_ind_var) {
           tau_p <- extract_pars(
             emulate_seeded(rv$meanfitList[[group]], rv$seedList[[sim_no]]),
             "position")[[1]]
@@ -1308,11 +1312,10 @@ mod_tab_hrange_server <- function(id, rv) {
         if (rv$grouped) fitB <- rv$modList[[2]]
       }
       
-      if (rv$is_emulate) {
+      if (rv$add_ind_var) {
         req(rv$meanfitList)
-        fit <- emulate_seeded(rv$meanfitList[["All"]], seed)
-        if (length(fit$isotropic) > 1)
-          fit$isotropic <- fit$isotropic[["sigma"]]
+        
+        fit <- simulate_seeded(rv$meanfitList[["All"]], seed)
         
         # Recenter to 0,0:
         fit$mu[["x"]] <- 0
@@ -1338,10 +1341,8 @@ mod_tab_hrange_server <- function(id, rv) {
         group <- get_group(seed, rv$groups[[2]])
         rv$hr$groups <- stats::setNames(list(seed), group)
         
-        if (rv$is_emulate) {
-          fit <- emulate_seeded(rv$meanfitList[[group]], seed)
-          if (length(fit$isotropic) > 1)
-            fit$isotropic <- fit$isotropic[["sigma"]]
+        if (rv$add_ind_var) {
+          fit <- simulate_seeded(rv$meanfitList[[group]], seed)
           
           # Recenter to 0,0:
           fit$mu[["x"]] <- 0
@@ -1559,8 +1560,8 @@ mod_tab_hrange_server <- function(id, rv) {
           seed = rv$seedList[[set_id]],
           sigma = rv$sigma,
           
-          emulated = rv$is_emulate,
-          fit = if (rv$is_emulate) rv$meanfitList else NULL,
+          ind_var = rv$add_ind_var,
+          fit = if (rv$add_ind_var) rv$meanfitList else NULL,
           
           grouped = rv$grouped,
           groups = if (rv$grouped) rv$hr$groups else NULL)
@@ -1602,7 +1603,7 @@ mod_tab_hrange_server <- function(id, rv) {
           group <- get_group(rv$seedList[[set_id]], rv$groups[[2]])
         }
         
-        if (rv$is_emulate) {
+        if (rv$add_ind_var) {
           tau_p <- extract_pars(
             emulate_seeded(rv$meanfitList[[group]],
                            rv$seedList[[set_id]]),
@@ -1764,8 +1765,8 @@ mod_tab_hrange_server <- function(id, rv) {
         seed = rv$seedList[[rv$hr_nsim]],
         sigma = rv$sigma,
         
-        emulated = rv$is_emulate,
-        fit = if (rv$is_emulate) rv$meanfitList else NULL,
+        ind_var = rv$add_ind_var,
+        fit = if (rv$add_ind_var) rv$meanfitList else NULL,
         
         grouped = rv$grouped,
         groups = if (rv$grouped) rv$hr$groups else NULL)
